@@ -164,7 +164,7 @@ def K2onSilicon(infile,fieldnum):
     ra_sources_deg, dec_sources_deg, mag = parse_file(infile)
 
     if np.shape(ra_sources_deg)[0] > 500:
-        print('There are {} sources in your target list, this could take some time'.format(np.size(ra_sources_deg)[0]))
+        print('There are {} sources in your target list, this could take some time'.format(np.shape(ra_sources_deg)[0]))
 
     ra_deg, dec_deg, scRoll_deg = getRaDecRollFromFieldnum(fieldnum)
 
